<?php

namespace Controllers;

use Exception\CustomException;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class Settings extends Simple {
    /** @var \Services\Settings */
    private $settingService;
    /** @var \Services\Password $passwordService */
    protected $passwordService;

    public function __construct(\Services\Settings $settingService, \Services\Password $passwordService) {
        $this->settingService  = $settingService;
        $this->passwordService = $passwordService;
    }

    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function findADConfiguration(Request\Filter $request, Response $response) {
        try {
            $adConfig = $this->settingService->findADConfigurationByNrOrg();
            $response->addDataSet(new DataSet ('adConfig', $adConfig));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     */
    public function saveADConfiguration(Request\DataSet $request, Response $response) {
        try {
            $adRows      = $request->getDataSet()->getRows();
            $adRow       = $adRows[0];
            $useAd       = $adRow['USE_AD'];
            $domain      = $adRow['DOMAIN'];
            $server      = $adRow['SERVER'];
            $admUser     = isset($adRow['ADM_USER']) ? $adRow['ADM_USER'] : null;
            $admPassword = isset($adRow['ADM_PASSWORD']) ? $adRow['ADM_PASSWORD'] : null;
            $adConfig    = $this->settingService->saveADConfiguration($domain, $server, $admUser, $admPassword, $useAd);
            $response->addDataSet(new DataSet ('adConfig', $adConfig));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function getOrganizationParameters(Request\Filter $request, Response $response) {
        try {
            $generalParameters  = $this->settingService->getOrganizationParameters();
            $generalParameters  = empty($generalParameters) ? array() : $generalParameters[0];
            $passwordParameters = $this->passwordService->findPasswordParameters();
            $passwordParameters = empty($passwordParameters) ? array() : $passwordParameters[0];
            $parameters = array_merge($generalParameters, $passwordParameters);
            $response->addDataSet(new DataSet ('parameters', array($parameters)));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     */
    public function saveOrganizationParameters(Request\DataSet $request, Response $response){
        try {
            $row = $request->getDataSet()->getRows()[0];
            $useRestriction = $row['USE_RESTRICTION'];
            $idUtCtrlSen    = $row['IDUTCTRLSEN'];
            $nrDiasExpSen   = $row['NRDIASEXPSEN'];
            $nrDiasAviso    = $row['NRDIASAVISO'];
            $nrAltSenhRep   = $row['NRALTSENHREP'];
            $cdPictSenha    = $row['CDPICTSENHA'];
            $nrErroSenha    = $row['NRERROSENHA'];
            $msgLoginEmailSuc = $row['DSMSGLOGINEMAILSUC'];
            $msgLoginEmailErr = $row['DSMSGLOGINEMAILERR'];
            $this->settingService->saveOrganizationParameters($useRestriction, $idUtCtrlSen, $nrDiasExpSen,
                $nrDiasAviso, $nrAltSenhRep, $cdPictSenha, $nrErroSenha, $msgLoginEmailSuc, $msgLoginEmailErr);
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function getOrganizationRestrictionByIp(Request\Filter $request, Response $response){
        try {
            $filters      = $request->getFilterCriteria()->getConditions();
            $restrictions = $this->settingService->getOrganizationRestrictionByIp($filters);
            $response->addDataSet(new DataSet ('organizationRestrictionByIp', $restrictions));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function saveOrganizationRestrictionByIp(Request\DataSet $request, Response $response){
        try {
            $row = $request->getDataSet()->getRows()[0];
            $ipv4 = isset($row['IPV4']) ? $row['IPV4'] : null;
            $ipv6 = isset($row['IPV6']) ? $row['IPV6'] : null;
            $ipRestrictedId = isset($row['ID']) ? $row['ID'] : null;
            $active = isset($row['ACTIVE']) ? $row['ACTIVE'] : null;
            $description = isset($row['DESCRIPTION']) ? $row['DESCRIPTION'] : null;
            $restrictionArrayId = $this->settingService->saveOrganizationRestrictionByIp($ipRestrictedId, $ipv4, $ipv6, $description, $active);
            $response->addDataSet(new DataSet ('organizationRestrictionByIp', $restrictionArrayId));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
    
    public function removeOrganizationRestrictionByIp(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            $restrictionId = $row['ID'];
            $this->settingService->removeOrganizationRestrictionByIp($restrictionId);
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
} 